@@ -110,6 +110,7 @@ def print_results(results):
     for res in results:
         vuln_occ_dict = res.to_dict()
         id = vuln_occ_dict.get("id")
+        package_type = vuln_occ_dict.get("type")
         if id not in added_list:
             package_issue = res.package_issue
             full_pkg = package_issue.affected_location.package
@@ -118,6 +119,8 @@ def print_results(results):
                     package_issue.affected_location.vendor,
                     package_issue.affected_location.package,
                 )
+            if package_type and package_type != "*":
+                full_pkg = package_type + ":" + full_pkg
             table.append(
                 [
                     id,
